diff --git a/xCAT-UI/js/guide/guide.js b/xCAT-UI/js/guide/guide.js
index 7e966d98a..d16e74958 100644
--- a/xCAT-UI/js/guide/guide.js
+++ b/xCAT-UI/js/guide/guide.js
@@ -1,9 +1,9 @@
-function loadManualPage(){
- // Create monitor tab
+function loadGuidePage(){
+ //create guide tab
var tab = new Tab();
tab.init();
$('#content').append(tab.object());
- //add the help content
+ //add the help content
var helpForm = $('
');
helpForm.append('